part of "create_command.dart";

void printSuccess(String message) {
  print('\u001b[32m$message\x1B[0m');
}

void installPackage(File pubspec, String package, String version, {bool devDep = false}) {
  String tempPubSpec = pubspec.readAsStringSync();
  if (devDep) {
    tempPubSpec = tempPubSpec.replaceFirst(
        "dev_dependencies:\n", "dev_dependencies:\n  $package: ^$version\n");
  } else {
    tempPubSpec =
        tempPubSpec.replaceFirst("dependencies:\n", "dependencies:\n  $package: ^$version\n");
  }
  pubspec.writeAsStringSync(tempPubSpec);
  printSuccess("Установлен $package версии $version");
}

void installFlutterLocalizationPackage(File pubspec) {
  String tempPubSpec = pubspec.readAsStringSync();
  tempPubSpec = tempPubSpec.replaceFirst("flutter:\n    sdk: flutter",
      "flutter:\n    sdk: flutter\n  flutter_localizations:\n    sdk: flutter\n");

  pubspec.writeAsStringSync(tempPubSpec);
  printSuccess("Установлен flutter_localization");
}

void installBasePackages(File pubspec) {
  print("Установка базовых зависимостей: ");
  installPackage(pubspec, "provider", "6.0.2");
  installPackage(pubspec, "flutter_bloc", "8.0.1");
  installPackage(pubspec, "freezed", "1.1.1");
  installPackage(pubspec, "dio", "4.0.4");
  installPackage(pubspec, "flutter_secure_storage", "5.0.2");
  installPackage(pubspec, "json_annotation", "4.4.0");
  installPackage(pubspec, "flutter_simple_dependency_injection", "2.0.0");
  installPackage(pubspec, "retrofit", "3.0.1+1");
  installPackage(pubspec, "path_provider", "2.0.9");
  installPackage(pubspec, "path", "1.8.0");
  installPackage(pubspec, "auto_route", "3.2.3+1");
  installPackage(pubspec, "modal_bottom_sheet", "2.0.0");
  installPackage(pubspec, "flutter_dotenv", "5.0.2");
  installPackage(pubspec, "either_dart", "0.1.4");
  installPackage(pubspec, "retrofit_generator", "4.0.1", devDep: true);
  installPackage(pubspec, "auto_route_generator", "3.2.3", devDep: true);
  installPackage(pubspec, "json_serializable", "6.1.4", devDep: true);
  installPackage(pubspec, "build_runner", "2.1.7", devDep: true);
  print("");
}

void installDatabase(File pubspec) {
  print("Установка зависимостей для базы данных: ");
  installPackage(pubspec, "drift", "1.4.0");
  installPackage(pubspec, "sqlite3_flutter_libs", "0.5.3");
  installPackage(pubspec, "drift_dev", "1.4.0", devDep: true);
  print("");
}

void installCookieManager(File pubspec) {
  print("Установка зависимостей для менеджера куков: ");
  installPackage(pubspec, "dio_cookie_manager", "2.0.0");
  print("");
}

void installLoaderKit(File pubspec) {
  print("Установка зависимостей для набора лоадеров: ");
  installPackage(pubspec, "flutter_spinkit", "5.1.0");
  print("");
}

void installAdaptiveDialog(File pubspec) {
  print("Установка зависимостей для нативных диалогов: ");
  installPackage(pubspec, "adaptive_dialog", "1.3.0");
  print("");
}

void installGlobalLoader(File pubspec) {
  print("Установка зависимостей для глобального лоадера: ");
  installPackage(pubspec, "loader_overlay", "2.0.5");
  print("");
}

void installDioCacheInterceptor(File pubspec) {
  print("Установка зависимостей для кеширующего обработчика: ");
  installPackage(pubspec, "dio_cache_interceptor", "3.2.2");
  installPackage(pubspec, "dio_cache_interceptor_db_store", "4.1.0");
  print("");
}

void installLocalization(File pubspec) {
  print("Установка зависимостей для локализации: ");
  installFlutterLocalizationPackage(pubspec);
  installPackage(pubspec, "fast_i18n", "5.11.0", devDep: true);
  print("");
}
